@@ -1,6 +1,6 @@
 !=======================================================================
 !
-!  PROGRAM  PHASE/0 2014.03 ($Rev: 409 $)
+!  PROGRAM  PHASE/0 2016.01 ($Rev: 440 $)
 !
 !  MODULE: m_Representation
 !
@@ -770,8 +770,8 @@ contains
   symbol_irrep(2) = "A2'"
   symbol_irrep(3) = 'A1"'
   symbol_irrep(4) = 'A2"'; active(4) = 'IR  '
-  symbol_irrep(5) = 'E" '; active(3) = 'R   '
-  symbol_irrep(6) = "E' "; active(4) = 'IR&R'
+  symbol_irrep(5) = 'E" '; active(5) = 'R   '         !! ASMS 2015/03/17
+  symbol_irrep(6) = "E' "; active(6) = 'IR&R'         !! ASMS 2015/03/17
 
   end subroutine set_symbol_d3h
 
